"""
    Module for the Open Webdriver.
"""

import os
import sys

from .open_webdriver import Driver  # type: ignore
from .open_webdriver import open_webdriver
